/*
-- Copyright INMOS Limited 1991
--
-- **************************************************************************
--
-- Group:	Iq software
--
-- Product:	IMS-F006 Ethernet TRAM support software
--
-- File:	b431load.c
--
-- Version:	1.0
--
-- **************************************************************************
--
-- Contains a function to download a standalone version of the IMS B431
-- device driver into the IMS B431 Ethernet TRAM. This is a single transputer
-- bootable (.BTL) that performs no ISERVER communication. The .BTL file was
-- converted into the static char array with the `bin2hdr' utility.
--
-- **************************************************************************
--
-- History:
--
-- (11-NOV-91) Bob Wipfel, Created file.
--
-- **************************************************************************
*/

#include <time.h>
#include <channel.h>
#include <process.h>

#include "imsb431.h"
#include "b431load.h"
#include "b431drvr.h"

int B431_Load_Driver(
	Channel	*from_b431,
	Channel *to_b431 )
{
	MESSAGE_HDR	header;

	if ( ChanOutTimeFail( to_b431, binary, sizeof(binary),
		ProcTimePlus( ProcTime(), (int) CLOCKS_PER_SEC ) ) == 1 )
		return( LOAD_BOOT_FAILED );

	INIT_MESSAGE_HDR( header, 0, FN_CHECK_ALIVE, 0 );

	if ( ChanOutTimeFail( to_b431, &header, sizeof(header),
		ProcTimePlus( ProcTime(), (int) CLOCKS_PER_SEC ) ) == 1 )
		return( LOAD_CHECK_FAILED );

	if ( ChanInTimeFail( from_b431, &header, sizeof(header),
		ProcTimePlus( ProcTime(), (int) CLOCKS_PER_SEC ) ) == 1 )
		return( LOAD_CHECK_FAILED );

	if ( header.fn_code == FN_CHECK_ALIVE )
		return( LOAD_SUCCESS );
	else
		return( LOAD_CHECK_FAILED );
}
