--
-- Copyright INMOS Limited 1991
--
-- **************************************************************************
--
-- Group:	Iq software
--
-- Product:	IMS-F006 Ethernet TRAM support software
--
-- File:	b431drvr.inc
--
-- Version:	1.0
--
-- **************************************************************************
--
-- Contains constants that define the private interface between the B431
-- device driver and the corresponding client libraries. A similar header
-- file exists that defines the public interface, ie: constants that users
-- of the client library will need in order to make the library calls.
--
-- The message passing protocol that the driver and client libraries adopt
-- is specified by this file.
--
-- **************************************************************************
--
-- History:	
--
-- (15-SEP-91) Bob Wipfel, Created file.
--
-- **************************************************************************
--

-- Messages are sent to and received from the driver on a transputer
-- channel. Messages are transferred using a fixed sized header followed
-- by variable length data. The length of the data part is contained within
-- the header. The header also contains a function code field, and an optional
-- simple result field. The function code is used to tag function request
-- or response messages and the simple result field can be used to return a
-- result code.

-- Message header, field offsets (in bytes)

VAL MESSAGE.HDR.LENGTH  IS 0 :  -- Length of the following data part
VAL MESSAGE.HDR.FN.CODE IS 2 :  -- Function code
VAL MESSAGE.HDR.RESULT  IS 3 :  -- Simple result code

VAL MESSAGE.HDR.SIZE    IS 4 :  -- Message header size

-- Function request messages implemented by the B431 driver

-- These messages are synchronous, the function code is carried both in
-- the request and the response message. The simple result field is used
-- to carry the result.

VAL FN.INIT.NORMAL   IS 1 (BYTE) :  -- Init interface in normal mode
VAL FN.INIT.LOOPBACK IS 2 (BYTE) :  -- Init interface in loopback mode
VAL FN.START.ETHER   IS 3 (BYTE) :  -- Start ethernet interface
VAL FN.CHECK.ALIVE   IS 4 (BYTE) :  -- Check device driver is alive

-- These messages are only ever sent to the driver. It does not send an
-- acknowledge message.

VAL FN.TX.PACKET1    IS 5 (BYTE) :  -- Send packet, type 1 parameters
VAL FN.TX.PACKET2    IS 6 (BYTE) :  -- Send packet, type 2 parameters
VAL FN.RESET.STATS   IS 7 (BYTE) :  -- Reset ethernet statistics

-- These messages are asynchronous, the function code is carried only in
-- the request message. The driver will send the response message when it
-- has completed the operation. In the meantime it may send other messages
-- to indicate the occurence of an event condition. The response function
-- and result codes are defined in a public header file.

VAL FN.STOP.ETHER    IS 8 (BYTE) :  -- Stop ethernet interface
VAL FN.TERMINATE     IS 9 (BYTE) :  -- Terminate device driver
VAL FN.ETHER.STATS   IS 10 (BYTE) :  -- Request ethernet statistics
